@@ -18,7 +18,10 @@ pub enum Error {
     InvalidAbbr(String),
 
     #[error("Value of arg `{0}` is invalid.")]
-    InvalidArgValue(String),
+    InvalidArgumentValue(String),
+
+    #[error(transparent)]
+    Args(#[from] pico_args::Error),
 
     #[error(transparent)]
     IO(#[from] std::io::Error),
@@ -26,14 +29,8 @@ pub enum Error {
     #[error("No path found.")]
     NoPathFound,
 
-    #[error("Abbreviation is empty.")]
-    EmptyAbbr,
-
-    #[error("Arg contains invalid UTF-8.")]
-    ArgInvalidUnicode,
-
-    #[error("Abbreviation contains wildcard at the last place.")]
-    WildcardAtLastPlace,
+    #[error("Invalid UTF-8 encountered.")]
+    InvalidUnicode,
 
     #[error("")]
     CtrlC,
